from setuptools import setup

setup(name='practice_distribution_msrk',
      version='1.0',
      description='Gaussian distributions',
      packages=['practice_distribution_msrk'],
      zip_safe=False,
      author='Satya Rohith Kumar',
      author_email='rohithmeduri24@gmail.com',
      requires=['matplotlib','math'],)
